@@ -1,10 +1,10 @@
 import warnings
-from typing import Callable, Optional, Tuple, Sequence
+from typing import Callable, Tuple, Sequence
 import numpy
 
 from .DelayedOp import DelayedOp
 from ._isometric import ISOMETRIC_OP_WITH_ARGS, _execute
-from .extract_dense_array import extract_dense_array, _sanitize_to_fortran
+from .extract_dense_array import extract_dense_array
 from .extract_sparse_array import extract_sparse_array
 from .create_dask_array import create_dask_array
 from .chunk_shape import chunk_shape
@@ -104,21 +104,20 @@ class BinaryIsometricOp(DelayedOp):
         return self._op
 
  
-def _extract_array(x: BinaryIsometricOp, subset: Optional[Tuple[Sequence[int], ...]], f: Callable):
+def _extract_array(x: BinaryIsometricOp, subset: Tuple[Sequence[int], ...], f: Callable):
     ls = f(x._left, subset)
     rs = f(x._right, subset)
     return _execute(ls, rs, x._op)
 
 
 @extract_dense_array.register
-def extract_dense_array_BinaryIsometricOp(x: BinaryIsometricOp, subset: Optional[Tuple[Sequence[int], ...]] = None):
+def extract_dense_array_BinaryIsometricOp(x: BinaryIsometricOp, subset: Tuple[Sequence[int], ...]):
     """See :py:meth:`~delayedarray.extract_dense_array.extract_dense_array`."""
-    out = _extract_array(x, subset, extract_dense_array)
-    return _sanitize_to_fortran(out)
+    return _extract_array(x, subset, extract_dense_array)
 
 
 @extract_sparse_array.register
-def extract_sparse_array_BinaryIsometricOp(x: BinaryIsometricOp, subset: Optional[Tuple[Sequence[int], ...]] = None):
+def extract_sparse_array_BinaryIsometricOp(x: BinaryIsometricOp, subset: Tuple[Sequence[int], ...]):
     """See :py:meth:`~delayedarray.extract_sparse_array.extract_sparse_array`."""
     return _extract_array(x, subset, extract_sparse_array)
 
