@@ -1,9 +1,10 @@
-from typing import Optional, Callable, Literal, Tuple, Sequence
+from typing import Callable, Literal, Tuple, Sequence
 import numpy
 from numpy import dtype, zeros
 
 from .DelayedOp import DelayedOp
-from .extract_dense_array import extract_dense_array, _sanitize_to_fortran
+from .SparseNdarray import SparseNdarray
+from .extract_dense_array import extract_dense_array
 from .extract_sparse_array import extract_sparse_array
 from .create_dask_array import create_dask_array
 from .chunk_shape import chunk_shape
@@ -110,21 +111,20 @@ class UnaryIsometricOpSimple(DelayedOp):
         return self._op
 
 
-def _extract_array(x: UnaryIsometricOpSimple, subset: Optional[Tuple[Sequence[int], ...]], f: Callable):
+def _extract_array(x: UnaryIsometricOpSimple, subset: Tuple[Sequence[int], ...], f: Callable):
     target = f(x._seed, subset)
     g = _choose_operator(x._op)
     return g(target)
 
 
 @extract_dense_array.register
-def extract_dense_array_UnaryIsometricOpSimple(x: UnaryIsometricOpSimple, subset: Optional[Tuple[Sequence[int], ...]] = None):
+def extract_dense_array_UnaryIsometricOpSimple(x: UnaryIsometricOpSimple, subset: Tuple[Sequence[int], ...]) -> numpy.ndarray:
     """See :py:meth:`~delayedarray.extract_dense_array.extract_dense_array`."""
-    out = _extract_array(x, subset, extract_dense_array)
-    return _sanitize_to_fortran(out)
+    return _extract_array(x, subset, extract_dense_array)
 
 
 @extract_sparse_array.register
-def extract_sparse_array_UnaryIsometricOpSimple(x: UnaryIsometricOpSimple, subset: Optional[Tuple[Sequence[int], ...]] = None):
+def extract_sparse_array_UnaryIsometricOpSimple(x: UnaryIsometricOpSimple, subset: Tuple[Sequence[int], ...]) -> SparseNdarray:
     """See :py:meth:`~delayedarray.extract_sparse_array.extract_sparse_array`."""
     return _extract_array(x, subset, extract_sparse_array)
 
