@@ -23,7 +23,7 @@ def test_BinaryIsometricOp_add(left_mask_rate, right_mask_rate):
     assert not delayedarray.is_sparse(z)
     assert delayedarray.is_masked(z) == (left_mask_rate + right_mask_rate > 0)
 
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y + y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y + y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -39,7 +39,7 @@ def test_BinaryIsometricOp_subtract(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y - y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y - y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -55,7 +55,7 @@ def test_BinaryIsometricOp_multiply(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y - y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y - y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -71,7 +71,7 @@ def test_BinaryIsometricOp_divide(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y / y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y / y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -87,7 +87,7 @@ def test_BinaryIsometricOp_modulo(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y % y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y % y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -103,7 +103,7 @@ def test_BinaryIsometricOp_floordivide(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y // y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y // y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -119,7 +119,7 @@ def test_BinaryIsometricOp_power(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y**y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y**y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -135,7 +135,7 @@ def test_BinaryIsometricOp_equal(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y == y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y == y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -151,7 +151,7 @@ def test_BinaryIsometricOp_not_equal(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y != y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y != y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -167,7 +167,7 @@ def test_BinaryIsometricOp_greater(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y > y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y > y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -183,7 +183,7 @@ def test_BinaryIsometricOp_greater_equal(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y >= y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y >= y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -199,7 +199,7 @@ def test_BinaryIsometricOp_less(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y < y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y < y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -215,7 +215,7 @@ def test_BinaryIsometricOp_less_than(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y <= y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y <= y2)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -231,7 +231,7 @@ def test_BinaryIsometricOp_logical_and(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_and(y, y2))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_and(y, y2))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -247,7 +247,7 @@ def test_BinaryIsometricOp_logical_or(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_or(y, y2))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_or(y, y2))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -263,7 +263,7 @@ def test_BinaryIsometricOp_logical_xor(left_mask_rate, right_mask_rate):
 
     assert isinstance(z, delayedarray.DelayedArray)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_xor(y, y2))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_xor(y, y2))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -287,23 +287,23 @@ def test_BinaryIsometricOp_subset(left_mask_rate, right_mask_rate):
 def test_BinaryIsometricOp_sparse(left_mask_rate, right_mask_rate):
     y = simulate_SparseNdarray((100, 50), mask_rate=left_mask_rate, density1=0.1)
     x = delayedarray.DelayedArray(y)
-    densed = delayedarray.extract_dense_array(y)
+    densed = delayedarray.to_dense_array(y)
 
     y2 = simulate_ndarray(y.shape, mask_rate=right_mask_rate)
     x2 = delayedarray.DelayedArray(y2)
     z = numpy.logical_xor(x != 0, x2 != 0)
     assert not delayedarray.is_sparse(z)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_xor(densed != 0, y2 != 0))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_xor(densed != 0, y2 != 0))
 
     z = x + x2
     assert not delayedarray.is_sparse(z)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), densed + y2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), densed + y2)
 
     y3 = simulate_SparseNdarray((100, 50), mask_rate=left_mask_rate, density1=0.1)
     x3 = delayedarray.DelayedArray(y3)
     z = x + x3
     assert delayedarray.is_sparse(z)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), densed + delayedarray.extract_dense_array(y3))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), densed + delayedarray.to_dense_array(y3))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -334,4 +334,4 @@ def test_BinaryIsometricOp_dask(left_mask_rate, right_mask_rate):
     import dask
     da = delayedarray.create_dask_array(z)
     assert isinstance(da, dask.array.core.Array)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), da.compute())
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), da.compute())
