@@ -16,13 +16,13 @@ def test_Transpose_simple(mask_rate):
     assert delayedarray.chunk_shape(t) == (23, 1)
     assert not delayedarray.is_sparse(t)
     assert delayedarray.is_masked(t) == (mask_rate > 0)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(t), y.T)
+    assert_identical_ndarrays(delayedarray.to_dense_array(t), y.T)
 
     t = numpy.transpose(x)
     assert isinstance(t.seed, delayedarray.Transpose)
     assert t.shape == (23, 30)
     assert not delayedarray.is_sparse(t)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(t), numpy.transpose(y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(t), numpy.transpose(y))
 
 
 @pytest.mark.parametrize("mask_rate", [0, 0.2])
@@ -33,12 +33,12 @@ def test_Transpose_more_dimensions(mask_rate):
     t = numpy.transpose(x, axes=(1, 2, 0))
     assert isinstance(t.seed, delayedarray.Transpose)
     assert t.shape == (23, 10, 30)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(t), numpy.transpose(y, axes=(1, 2, 0)))
+    assert_identical_ndarrays(delayedarray.to_dense_array(t), numpy.transpose(y, axes=(1, 2, 0)))
 
     t = numpy.transpose(x)
     assert isinstance(t.seed, delayedarray.Transpose)
     assert t.shape == (10, 23, 30)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(t), numpy.transpose(y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(t), numpy.transpose(y))
 
 
 @pytest.mark.parametrize("mask_rate", [0, 0.2])
@@ -55,11 +55,11 @@ def test_Transpose_subset(mask_rate):
 def test_Transpose_sparse(mask_rate):
     y = simulate_SparseNdarray((30, 23), mask_rate=mask_rate)
     x = delayedarray.DelayedArray(y)
-    densed = delayedarray.extract_dense_array(y)
+    densed = delayedarray.to_dense_array(y)
 
     t = numpy.transpose(x)
     assert delayedarray.is_sparse(t)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(t), densed.T)
+    assert_identical_ndarrays(delayedarray.to_dense_array(t), densed.T)
 
 
 @pytest.mark.parametrize("mask_rate", [0, 0.2])
@@ -71,4 +71,4 @@ def test_Transpose_dask(mask_rate):
     import dask
     da = delayedarray.create_dask_array(t)
     assert isinstance(da, dask.array.core.Array)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(t), da.compute())
+    assert_identical_ndarrays(delayedarray.to_dense_array(t), da.compute())
