@@ -44,7 +44,7 @@ def test_UnaryIsometricOpSimple_basic(mask_rate):
             warnings.simplefilter("ignore")
             ufunc = getattr(numpy, op)
             z = ufunc(x)
-            obs = delayedarray.extract_dense_array(z)
+            obs = delayedarray.to_dense_array(z)
             da = delayedarray.create_dask_array(z).compute()
             expected = ufunc(y)
 
@@ -68,7 +68,7 @@ def test_UnaryIsometricOpSimple_logical_not(mask_rate):
 
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpSimple)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_not(y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_not(y))
 
 
 @pytest.mark.parametrize("mask_rate", [0, 0.2])
@@ -82,7 +82,7 @@ def test_UnaryIsometricOpSimple_abs(mask_rate):
 
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpSimple)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), abs(y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), abs(y))
 
 
 @pytest.mark.parametrize("mask_rate", [0, 0.2])
@@ -101,12 +101,12 @@ def test_UnaryIsometricOpSimple_subset(mask_rate):
 def test_UnaryIsometricOpSimple_sparse(mask_rate):
     y = simulate_SparseNdarray((20, 50), density1=0.15, mask_rate=mask_rate)
     x = delayedarray.DelayedArray(y)
-    densed = delayedarray.extract_dense_array(y)
+    densed = delayedarray.to_dense_array(y)
 
     z = numpy.exp(x)
     assert not delayedarray.is_sparse(z)
-    assert_identical_ndarrays(numpy.exp(densed), delayedarray.extract_dense_array(z))
+    assert_identical_ndarrays(numpy.exp(densed), delayedarray.to_dense_array(z))
 
     z = numpy.log1p(x)
     assert delayedarray.is_sparse(z)
-    assert_identical_ndarrays(numpy.log1p(densed), delayedarray.extract_dense_array(z))
+    assert_identical_ndarrays(numpy.log1p(densed), delayedarray.to_dense_array(z))
