@@ -22,7 +22,7 @@ def test_UnaryIsometricOpWithArgs_basics(mask_rate):
     assert z.seed.value == 2
     assert z.seed.along is None
 
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y + 2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y + 2)
     assert delayedarray.chunk_shape(z) == (1, 15)
 
 
@@ -37,26 +37,26 @@ def test_UnaryIsometricOpWithArgs_add(left_mask_rate, right_mask_rate):
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert not delayedarray.is_sparse(z)
     assert delayedarray.is_masked(z) == (left_mask_rate > 0)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y + 2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y + 2)
 
     z = 5 + x
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y + 5)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y + 5)
 
     v = simulate_ndarray((15,), mask_rate=right_mask_rate)
     z = x + v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert delayedarray.is_masked(z) == (left_mask_rate + right_mask_rate > 0)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y + v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y + v)
     assert z.seed.along == 1
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v + x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v + y)
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v + y)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -69,24 +69,24 @@ def test_UnaryIsometricOpWithArgs_subtract(left_mask_rate, right_mask_rate):
     z = x - 2
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y - 2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y - 2)
 
     z = 5 - x
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), 5 - y)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), 5 - y)
 
     v = simulate_ndarray((15,), mask_rate=right_mask_rate)
     z = x - v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y - v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y - v)
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v - x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v - y)
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v - y)
 
 
 @pytest.mark.parametrize("mask_rate", [0, 0.2])
@@ -99,7 +99,7 @@ def test_UnaryIsometricOpWithArgs_negate(mask_rate):
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert not delayedarray.is_sparse(z)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), -y)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), -y)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -112,24 +112,24 @@ def test_UnaryIsometricOpWithArgs_multiply(left_mask_rate, right_mask_rate):
     z = x * 2
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y * 2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y * 2)
 
     z = 5 * x
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), 5 * y)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), 5 * y)
 
     v = simulate_ndarray((25,), mask_rate=right_mask_rate)
     z = x * v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y * v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y * v)
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v * x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v * y)
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v * y)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -142,24 +142,24 @@ def test_UnaryIsometricOpWithArgs_divide(left_mask_rate, right_mask_rate):
     z = x / 2
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y / 2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y / 2)
 
     z = 5 / (x + 1)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), 5 / (y + 1))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), 5 / (y + 1))
 
     v = simulate_ndarray((25,), mask_rate=right_mask_rate)
     z = x / v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y / v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y / v)
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v / (x + 1)
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v / (y + 1))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v / (y + 1))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -172,24 +172,24 @@ def test_UnaryIsometricOpWithArgs_modulo(left_mask_rate, right_mask_rate):
     z = x % 2
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y % 2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y % 2)
 
     z = 5 % (x + 1)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), 5 % (y + 1))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), 5 % (y + 1))
 
     v = simulate_ndarray((44,), mask_rate=right_mask_rate)
     z = x % v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y % v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y % v)
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v % (x + 1)
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v % (y + 1))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v % (y + 1))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -202,24 +202,24 @@ def test_UnaryIsometricOpWithArgs_floordivide(left_mask_rate, right_mask_rate):
     z = x // 2
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y // 2)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y // 2)
 
     z = 5 // (x + 1)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), 5 // (y + 1))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), 5 // (y + 1))
 
     v = simulate_ndarray((55,), mask_rate=right_mask_rate)
     z = x // v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y // v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y // v)
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v // (x + 1)
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v // (y + 1))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v // (y + 1))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -233,25 +233,25 @@ def test_UnaryIsometricOpWithArgs_power(left_mask_rate, right_mask_rate):
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
     assert numpy.allclose(
-        delayedarray.extract_dense_array(z), y**2
+        delayedarray.to_dense_array(z), y**2
     )  # guess if it's 2, it uses a special squaring, and the numeric precision changes.
 
     z = 5**x
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), 5**y)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), 5**y)
 
     v = simulate_ndarray((55,), mask_rate=right_mask_rate)
     z = x**v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y**v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y**v)
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v**x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v**y)
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v**y)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -265,11 +265,11 @@ def test_UnaryIsometricOpWithArgs_equal(left_mask_rate, right_mask_rate):
     z = x == val
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y == val))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y == val))
 
     val = x[1,1,1]
     z = val == x
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y == val))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y == val))
 
     # Generating something that could actually compare equal for a proper test.
     v = y[2,3,:]
@@ -281,13 +281,13 @@ def test_UnaryIsometricOpWithArgs_equal(left_mask_rate, right_mask_rate):
     z = x == v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (v == y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (v == y))
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v == x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), (v == y))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), (v == y))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -301,11 +301,11 @@ def test_UnaryIsometricOpWithArgs_not_equal(left_mask_rate, right_mask_rate):
     z = x != val
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y != val))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y != val))
 
     val = x[1,1]
     z = val != x
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y != val))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y != val))
 
     # Generating something that could actually compare equal for a proper test.
     v = y[2,:]
@@ -317,13 +317,13 @@ def test_UnaryIsometricOpWithArgs_not_equal(left_mask_rate, right_mask_rate):
     z = x != v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (v != y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (v != y))
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v != x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), (v != y))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), (v != y))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -336,22 +336,22 @@ def test_UnaryIsometricOpWithArgs_greater(left_mask_rate, right_mask_rate):
     z = x > 0.5
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y > 0.5))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y > 0.5))
 
     z = 0.2 > x
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y < 0.2))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y < 0.2))
 
     v = simulate_ndarray((11,), mask_rate=right_mask_rate)
     z = x > v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y > v))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y > v))
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v > x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), (v > y))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), (v > y))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -364,22 +364,22 @@ def test_UnaryIsometricOpWithArgs_greater_equal(left_mask_rate, right_mask_rate)
     z = x >= 0.2
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y >= 0.2))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y >= 0.2))
 
     z = 0.2 >= x
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y <= 0.2))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y <= 0.2))
 
     v = simulate_ndarray((13,), mask_rate=right_mask_rate)
     z = x >= v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y >= v))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y >= v))
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v >= x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), (v >= y))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), (v >= y))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -392,22 +392,22 @@ def test_UnaryIsometricOpWithArgs_less(left_mask_rate, right_mask_rate):
     z = x < 0.8
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y < 0.8))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y < 0.8))
 
     z = 0.4 < x
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y > 0.4))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y > 0.4))
 
     v = simulate_ndarray((13,), mask_rate=right_mask_rate)
     z = x < v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y < v))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y < v))
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v < x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), (v < y))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), (v < y))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -420,22 +420,22 @@ def test_UnaryIsometricOpWithArgs_less_than(left_mask_rate, right_mask_rate):
     z = x <= 0.7
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y <= 0.7))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y <= 0.7))
 
     z = 0.2 <= x
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y >= 0.2))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y >= 0.2))
 
     v = simulate_ndarray((33,), mask_rate=right_mask_rate)
     z = x <= v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), (y <= v))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), (y <= v))
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v <= x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), (v <= y))
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), (v <= y))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -448,21 +448,21 @@ def test_UnaryIsometricOpWithArgs_logical_and(left_mask_rate, right_mask_rate):
     z = numpy.logical_and(x, True)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_and(y, True))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_and(y, True))
 
     z = numpy.logical_and(False, x)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_and(y, False))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_and(y, False))
 
     v = simulate_ndarray((33,), dtype=numpy.dtype("bool"), mask_rate=right_mask_rate)
     z = numpy.logical_and(v, x)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_and(v, y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_and(v, y))
 
     z = numpy.logical_and(x, v)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_and(y, v))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_and(y, v))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -475,21 +475,21 @@ def test_UnaryIsometricOpWithArgs_logical_or(left_mask_rate, right_mask_rate):
     z = numpy.logical_or(x, True)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_or(y, True))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_or(y, True))
 
     z = numpy.logical_or(False, x)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_or(y, False))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_or(y, False))
 
     v = simulate_ndarray((55,), dtype=numpy.dtype("bool"), mask_rate=right_mask_rate)
     z = numpy.logical_or(v, x)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_or(v, y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_or(v, y))
 
     z = numpy.logical_or(x, v)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_or(y, v))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_or(y, v))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -502,21 +502,21 @@ def test_UnaryIsometricOpWithArgs_logical_xor(left_mask_rate, right_mask_rate):
     z = numpy.logical_xor(x, True)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_xor(y, True))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_xor(y, True))
 
     z = numpy.logical_xor(False, x)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_xor(y, False))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_xor(y, False))
 
     v = simulate_ndarray((55,), dtype=numpy.dtype("bool"), mask_rate=right_mask_rate)
     z = numpy.logical_xor(v, x)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_xor(v, y))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_xor(v, y))
 
     z = numpy.logical_xor(x, v)
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), numpy.logical_xor(y, v))
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), numpy.logical_xor(y, v))
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -524,20 +524,20 @@ def test_UnaryIsometricOpWithArgs_logical_xor(left_mask_rate, right_mask_rate):
 def test_UnaryIsometricOpWithArgs_sparse(left_mask_rate, right_mask_rate):
     y = simulate_SparseNdarray((100, 50), density1=0.1, mask_rate=left_mask_rate)
     x = delayedarray.DelayedArray(y)
-    densed = delayedarray.extract_dense_array(y)
+    densed = delayedarray.to_dense_array(y)
     z = x + 1
     assert not delayedarray.is_sparse(z)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), densed + 1)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), densed + 1)
 
     v = simulate_ndarray((50,), mask_rate=right_mask_rate)
     z = x / v
     assert delayedarray.is_sparse(z)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), densed / v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), densed / v)
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v * x
         assert delayedarray.is_sparse(z)
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v * densed)
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v * densed)
 
 
 @pytest.mark.parametrize("left_mask_rate", [0, 0.2])
@@ -550,28 +550,28 @@ def test_UnaryIsometricOpWithArgs_with_array(left_mask_rate, right_mask_rate):
     z = x + v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y + v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y + v)
     assert z.seed.along == 0
 
     v = simulate_ndarray((1, 20, 1), mask_rate=right_mask_rate)
     z = x + v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y + v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y + v)
     assert z.seed.along == 1
 
     v = simulate_ndarray((1, 1, 30), mask_rate=right_mask_rate)
     z = x + v
     assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
     assert z.shape == x.shape
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), y + v)
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), y + v)
     assert z.seed.along == 2 
 
     if right_mask_rate == 0: # due to bug in MaskedArray ufunc dispatch.
         z = v * x
         assert isinstance(z.seed, delayedarray.UnaryIsometricOpWithArgs)
         assert z.shape == x.shape
-        assert_identical_ndarrays(delayedarray.extract_dense_array(z), v * y)
+        assert_identical_ndarrays(delayedarray.to_dense_array(z), v * y)
         assert z.seed.along == 2
 
 
@@ -612,4 +612,4 @@ def test_UnaryIsometricOpWithArgs_dask(mask_rate):
     import dask.array
     da = delayedarray.create_dask_array(z)
     assert isinstance(da, dask.array.core.Array)
-    assert_identical_ndarrays(delayedarray.extract_dense_array(z), da.compute())
+    assert_identical_ndarrays(delayedarray.to_dense_array(z), da.compute())
