@@ -27,19 +27,24 @@ def chunk_shape_ChunkyBoi(x: _ChunkyBoi):
 
 def test_choose_block_size_for_1d_iteration():
     x = np.random.rand(100, 10)
-    assert da.choose_block_size_for_1d_iteration(x, 0, memory=800) == 10
-    assert da.choose_block_size_for_1d_iteration(x, 1, memory=800) == 1
+    assert da.choose_block_size_for_1d_iteration(x, 0, buffer_size=800) == 10
+    assert da.choose_block_size_for_1d_iteration(x, 1, buffer_size=800) == 1
 
-    # No memory.
-    assert da.choose_block_size_for_1d_iteration(x, 0, memory=0) == 1
-    assert da.choose_block_size_for_1d_iteration(x, 1, memory=0) == 1
+    # No buffer_size.
+    assert da.choose_block_size_for_1d_iteration(x, 0, buffer_size=0) == 1
+    assert da.choose_block_size_for_1d_iteration(x, 1, buffer_size=0) == 1
+
+    # Behaves correctly with empty objects.
+    empty = np.random.rand(100, 0)
+    assert da.choose_block_size_for_1d_iteration(empty, 0) == 100
+    assert da.choose_block_size_for_1d_iteration(empty, 1) == 1
 
     # Making a slightly more complex situation.
     x = _ChunkyBoi((100, 200), (20, 25))
-    assert da.choose_block_size_for_1d_iteration(x, 0, memory=4000) == 2
-    assert da.choose_block_size_for_1d_iteration(x, 1, memory=4000) == 5
-    assert da.choose_block_size_for_1d_iteration(x, 0, memory=40000) == 20
-    assert da.choose_block_size_for_1d_iteration(x, 1, memory=40000) == 50
+    assert da.choose_block_size_for_1d_iteration(x, 0, buffer_size=4000) == 2
+    assert da.choose_block_size_for_1d_iteration(x, 1, buffer_size=4000) == 5
+    assert da.choose_block_size_for_1d_iteration(x, 0, buffer_size=40000) == 20
+    assert da.choose_block_size_for_1d_iteration(x, 1, buffer_size=40000) == 50
 
 
 def _dense_sum(position, block):
@@ -125,3 +130,12 @@ def test_apply_over_dimension_sparse(mask_rate):
     assert np.allclose(expected, sum(y[1] for y in output))
     assert output[0][0] == (0, 7)
     assert output[-1][0] == (196, 200)
+
+
+def test_apply_over_dimension_empty():
+    x = np.ndarray([100, 0])
+    output = da.apply_over_dimension(x, 0, _dense_sum)
+    assert len(output) == 1
+
+    output = da.apply_over_dimension(x, 1, _dense_sum)
+    assert len(output) == 0
